@@ -12,6 +12,7 @@
 from __future__ import annotations
 
 import base64
+from datetime import datetime, date
 import glob
 import json
 import logging
@@ -37,6 +38,7 @@ if typing.TYPE_CHECKING:
     from google.cloud import bigquery
 
 from .exceptions import AnamlError, Reason
+from .models.preview_summary import PreviewSummary
 from .models.summary_statistics import (
     CategoricalSummaryStatistics, EmptySummaryStatistics, NumericalSummaryStatistics,
     SummaryStatistics
@@ -327,30 +329,60 @@ class Anaml:
         _ = self._json_or_handle_errors(r)
         return self.get_feature_by_id(int(feature.id.value))
 
-    def preview_feature(self, feature: Union[List[Feature], Feature]) -> List[SummaryStatistics]:
+    def preview_feature(
+            self,
+            feature: Union[List[Feature], Feature],
+            *,
+            entity: Optional[EntityId] = None,
+            snapshot_date: Optional[Union[str, date]] = None
+    ) -> List[PreviewSummary]:
         """Returns list of feature statistics.
 
         Args:
             feature: a Feature object or list of feature objects.
+            entity:  Entity Id to filter feature preview on.
+            snapshot_date: Date to filter feature preview on.
         """
         if isinstance(feature, list):
             req = {"features": [f.to_json() for f in feature]}
         else:
             req = {"features": [feature.to_json()]}
+
+        req["entity"] = entity
+
+        if isinstance(snapshot_date, str):
+            try:
+                datetime.strptime(snapshot_date, "%Y-%m-%d")
+                req["snapshotDate"] = snapshot_date
+            except ValueError:
+                raise ValueError(f"snapshotDate: {snapshot_date} provided is not of the format 'yyyy-mm-dd'")
+        elif isinstance(snapshot_date, date):
+            req["snapshotDate"] = snapshot_date.strftime("%Y-%m-%d")
+        else:
+            req["snapshotDate"] = None
+
         r = self._post("/feature-preview", json=req)
         result = self._json_or_handle_errors(r)
         return [
-            SummaryStatistics.from_json(fs)
+            PreviewSummary.from_json(fs)
             for fs in result.get('previewData', {}).get('featureStatistics', [])
         ]
 
-    def preview_feature_and_plot(self, feature: Union[List[Feature], Feature]) -> None:
+    def preview_feature_and_plot(
+            self,
+            feature: Union[List[Feature], Feature],
+            *,
+            entity: Optional[EntityId] = None,
+            snapshot_date: Optional[Union[str, datetime.date]] = None
+    ) -> None:
         """Show a matplotlib plot for the preview statistics of a feature.
 
         Args:
             feature: a Feature object
+            entity:  Entity Id to filter feature previews on.
+            snapshot_date: Date to filter feature preview on.
         """
-        feature_stats = self.preview_feature(feature)
+        feature_stats = self.preview_feature(feature, entity, snapshot_date)
         for fs in feature_stats:
             self._build_feature_plots(fs)
         self._warn_empty_feature_stats([
@@ -546,14 +578,34 @@ class Anaml:
         result = self._json_or_handle_errors(r)
         return FeatureSet.from_json(result)
 
-    def preview_feature_set(self, feature_set: Union[FeatureSet, FeatureSetCreationRequest]) -> pandas.DataFrame:
+    def preview_feature_set(
+            self,
+            feature_set: Union[FeatureSet, FeatureSetCreationRequest],
+            *,
+            entity: Optional[EntityId] = None,
+            snapshot_date: Optional[Union[str, datetime.date]] = None
+    ) -> pandas.DataFrame:
         """Returns a pandas dataframe of the feature set.
 
         Args:
             feature_set: a FeatureSet object.
+            entity:  Entity Id to filter feature preview on.
+            snapshot_date: Date to filter feature preview on.
         """
         import pandas
         req = {"featureSet": feature_set.to_json()}
+        req["entity"] = entity
+        if isinstance(snapshot_date, str):
+            try:
+                datetime.strptime(snapshot_date, "%Y-%m-%d")
+                req["snapshotDate"] = snapshot_date
+            except ValueError:
+                raise ValueError(f"snapshotDate: {snapshot_date} provided is not of the format 'yyyy-mm-dd'")
+        elif isinstance(snapshot_date, datetime):
+            req["snapshotDate"] = snapshot_date.strftime("%Y-%m-%d")
+        else:
+            req["snapshotDate"] = None
+
         r = self._post("/feature-set-preview", json=req)
         result = self._json_or_handle_errors(r)
         table_preview = TablePreview.from_json(result.get('previewData', {}))
@@ -1145,7 +1197,6 @@ class Anaml:
                 response_json = r.json()
                 if "errors" in response_json:
                     ex = AnamlError.from_json(response_json)
-                    self._log.error("The Anaml server reported an error", ex)
                     raise ex
             except json.decoder.JSONDecodeError:
                 # This is not unexpected. 404 responses, in particular, often have no JSON error message.
